@@ -1,12 +1,14 @@
 #include <stdio.h>
 #include <string.h>
 
+#include "ffi_test.h"
+
 struct some_struct {
 	int   some_int;
 	char *some_str;
 };
 
-extern void take_one_struct(struct some_struct *arg) {
+extern EXPORT void take_one_struct(struct some_struct *arg) {
 	if (arg -> some_int == 42)
 		printf("ok - got passed int 42\n");
 	else
@@ -25,7 +27,7 @@ extern void take_one_struct(struct some_struct *arg) {
 	fflush(stdout);
 }
 
-extern void return_one_struct(struct some_struct *arg) {
+extern EXPORT void return_one_struct(struct some_struct *arg) {
 	arg -> some_int = 42;
 	arg -> some_str = strdup("hello");
 }
